==> commons-compress-1.26.0-src.tar.gz: commons-compress-1.26.0-src/src/test/java/org/apache/commons/compress/compressors/TestCompressorStreamProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.commons.compress.compressors;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.Set;

import org.apache.commons.compress.utils.Sets;

public class TestCompressorStreamProvider implements CompressorStreamProvider {

    public static final class InvocationConfirmationException extends CompressorException {

        private static final long serialVersionUID = 1L;

        public InvocationConfirmationException(final String message) {
            super(message);
        }
    }

    @Override
    public CompressorInputStream createCompressorInputStream(final String name, final InputStream in, final boolean decompressConcatenated)
            throws CompressorException {
        throw new InvocationConfirmationException(name);
    }

    @Override
    public CompressorOutputStream createCompressorOutputStream(final String name, final OutputStream out) throws CompressorException {
        throw new InvocationConfirmationException(name);
    }

    @Override
    public Set<String> getInputStreamCompressorNames() {
        return Sets.newHashSet("TestInput1");
    }

    @Override
    public Set<String> getOutputStreamCompressorNames() {
        return Sets.newHashSet("TestOutput1");
    }

}

==> commons-compress-1.28.0-src.tar.gz: commons-compress-1.28.0-src/src/test/java/org/apache/commons/compress/compressors/TestCompressorStreamProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.commons.compress.compressors;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.Set;

import org.apache.commons.compress.utils.Sets;

public class TestCompressorStreamProvider implements CompressorStreamProvider {

    public static final class InvocationConfirmationException extends CompressorException {

        private static final long serialVersionUID = 1L;

        public InvocationConfirmationException(final String message) {
            super(message);
        }
    }

    @Override
    public CompressorInputStream createCompressorInputStream(final String name, final InputStream in, final boolean decompressConcatenated)
            throws CompressorException {
        throw new InvocationConfirmationException(name);
    }

    @Override
    public <T extends OutputStream> CompressorOutputStream<T> createCompressorOutputStream(final String name, final T out) throws CompressorException {
        throw new InvocationConfirmationException(name);
    }

    @Override
    public Set<String> getInputStreamCompressorNames() {
        return Sets.newHashSet("TestInput1");
    }

    @Override
    public Set<String> getOutputStreamCompressorNames() {
        return Sets.newHashSet("TestOutput1");
    }

}
